package eu.svjatoslav.inspector.java.commandline;


import eu.svjatoslav.commons.cli_helper.parameter_parser.Parser;
import eu.svjatoslav.commons.cli_helper.parameter_parser.parameter.*;

public class CommandlineConfiguration {

    public FileParameters jarFiles;
    public StringParameter graphName;
    private NullParameter showDebug;
    public StringParameters whitelistGlob;
    public StringParameters blacklistGlob;
    public StringParameters rootClasses;
    public NullParameter showHelp;
    public TargetImageTypeParameter targetImageType;
    public NullParameter keepDotFile;
    public DirectoryParameter targetDirectory;
    public DirectoryParameters classPaths;
    public final boolean configurationOk;
    public NullParameter hideOrphanedClasses;
    Parser parser;

    public static final String DEFAULT_GRAPH_NAME = "graph";

    public CommandlineConfiguration(String[] args) {
        parser = buildCommandlineParameterParser();
        configurationOk = parser.parse(args);
    }

    public boolean isDebug() {
        return showDebug.isSpecified();
    }

    public Parser buildCommandlineParameterParser() {
        Parser parser = new Parser();

        jarFiles = parser.add(
                new FileParameters("JAR file(s) to render."))
                .mustExist()
                .addAliases("-j");

        classPaths = parser.add(
                        new DirectoryParameters("Classpath directories"))
                .mustExist()
                .addAliases("-c");

        graphName = parser.add(
                new StringParameter("Graph name. (default: \"" + DEFAULT_GRAPH_NAME + "\")", DEFAULT_GRAPH_NAME))
                .addAliases("-n");

        showDebug = parser.add(
                new NullParameter("Show debug info."))
                .addAliases("--debug");

        showHelp = parser.add(new NullParameter("Show commandline usage help."))
                .addAliases("-h", "--help");

        keepDotFile = parser.add(
                new NullParameter("Keep dot file."))
                .addAliases("-k");

        hideOrphanedClasses = parser.add(
                new NullParameter("Hide orphaned classes."))
                .addAliases("-ho");

        whitelistGlob = parser.add(
                new StringParameters("Whitelist glob(s)."))
                .addAliases("-w");

        blacklistGlob = parser.add(
                new StringParameters("Blacklist glob(s)."))
                .addAliases("-b");

        rootClasses = parser.add(
                        new StringParameters("root class(es)."))
                .addAliases("-r");


        targetDirectory = parser.add(new DirectoryParameter("Target directory. " +
                "Default is current directory.").mustExist())
                .addAliases("-d");

        targetImageType = parser.add(new TargetImageTypeParameter()).addAliases("-t");

        return parser;
    }

}
